@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013,2015-2016 Aurimas Cernius
+ * Copyright (C) 2012-2013,2015-2017 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,8 +22,6 @@
 #define __ACTIONMANAGER_HPP_
 
 #include <map>
-#include <string>
-#include <list>
 
 #include <glibmm/variant.h>
 #include <giomm/menu.h>
@@ -41,23 +39,23 @@ class ActionManager
 public:
   ActionManager();
 
-  virtual Glib::RefPtr<Gio::SimpleAction> get_app_action(const std::string & name) const override;
+  virtual Glib::RefPtr<Gio::SimpleAction> get_app_action(const Glib::ustring & name) const override;
   const std::vector<Glib::RefPtr<Gio::SimpleAction> > & get_app_actions() const
     {
       return m_app_actions;
     }
-  virtual Glib::RefPtr<Gio::SimpleAction> add_app_action(const std::string & name) override;
-  virtual void add_app_menu_item(int section, int order, const std::string & label,
-                                 const std::string & action_def) override;
+  virtual Glib::RefPtr<Gio::SimpleAction> add_app_action(const Glib::ustring & name) override;
+  virtual void add_app_menu_item(int section, int order, const Glib::ustring & label,
+                                 const Glib::ustring & action_def) override;
   Glib::RefPtr<Gio::Menu> get_app_menu() const;
   virtual void register_main_window_action(const Glib::ustring & action, const Glib::VariantType *state_type,
     bool modifying = true) override;
   virtual std::map<Glib::ustring, const Glib::VariantType*> get_main_window_actions() const override;
   virtual bool is_modifying_main_window_action(const Glib::ustring & action) const override;
 
-  virtual void register_main_window_search_callback(const std::string & id, const Glib::ustring & action,
+  virtual void register_main_window_search_callback(const Glib::ustring & id, const Glib::ustring & action,
                                                     sigc::slot<void, const Glib::VariantBase&> callback) override;
-  virtual void unregister_main_window_search_callback(const std::string & id) override;
+  virtual void unregister_main_window_search_callback(const Glib::ustring & id) override;
   virtual std::map<Glib::ustring, sigc::slot<void, const Glib::VariantBase&>> get_main_window_search_callbacks() override;
 private:
   void make_app_actions();
@@ -69,10 +67,10 @@ private:
   struct AppMenuItem
   {
     int order;
-    std::string label;
-    std::string action_def;
+    Glib::ustring label;
+    Glib::ustring action_def;
 
-    AppMenuItem(int ord, const std::string & lbl, const std::string & act_def)
+    AppMenuItem(int ord, const Glib::ustring & lbl, const Glib::ustring & act_def)
       : order(ord)
       , label(lbl)
       , action_def(act_def)
@@ -90,7 +88,7 @@ private:
   AppMenuItemMultiMap m_app_menu_items;
   std::map<Glib::ustring, const Glib::VariantType*> m_main_window_actions;
   std::vector<Glib::ustring> m_non_modifying_actions;
-  std::map<std::string, std::pair<Glib::ustring, sigc::slot<void, const Glib::VariantBase&>>> m_main_window_search_actions;
+  std::map<Glib::ustring, std::pair<Glib::ustring, sigc::slot<void, const Glib::VariantBase&>>> m_main_window_search_actions;
 };
 
 
