@@ -78,7 +78,7 @@ void ExportToHtmlNoteAddin::on_note_opened()
 std::map<int, Gtk::Widget*> ExportToHtmlNoteAddin::get_actions_popover_widgets() const
 {
   auto widgets = NoteAddin::get_actions_popover_widgets();
-  auto button = gnote::utils::create_popover_button("win.exporttohtml-export", _("Export to HTML"));
+  auto button = gnote::utils::create_popover_button("win.exporttohtml-export", _("Export to HTML…"));
   gnote::utils::add_item_to_ordered_map(widgets, gnote::EXPORT_TO_HTML_ORDER, button);
   return widgets;
 }
@@ -114,7 +114,7 @@ void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
 
     try {
       sharp::Uri output_uri(output_path);
-      gnote::utils::open_url("file://" + output_uri.get_absolute_uri());
+      gnote::utils::open_url(*get_host_window(), "file://" + output_uri.get_absolute_uri());
     } 
     catch (const Glib::Exception & ex) {
       ERR_OUT(_("Could not open exported note in a web browser: %s"),
