@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,15 +61,15 @@ public:
   virtual bool save_configuration() override;
   virtual void reset_configuration() override;
   virtual bool is_configured() override;
-  virtual std::string name() override;
-  virtual std::string id() override;
+  virtual Glib::ustring name() override;
+  virtual Glib::ustring id() override;
   virtual bool is_supported() override;
   virtual bool initialized() override;
 private:
-  bool get_config_settings(std::string & syncPath);
+  bool get_config_settings(Glib::ustring & syncPath);
 
   Gtk::FileChooserButton *m_path_button;
-  std::string m_path;
+  Glib::ustring m_path;
   bool m_initialized;
   bool m_enabled;
 };
