@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -65,8 +65,8 @@ public:
   virtual void shutdown() override;
   virtual bool initialized() override;
 private:
-  static std::string get_id(const std::string & path);
-  static std::string make_uri(const std::string & note_id);
+  static Glib::ustring get_id(const Glib::ustring & path);
+  static Glib::ustring make_uri(const Glib::ustring & note_id);
 
   NoteDirectoryWatcherApplicationAddin();
   void handle_note_saved(const gnote::NoteBase::Ptr &);
@@ -74,15 +74,15 @@ private:
                                        const Glib::RefPtr<Gio::File> & other_file,
                                        Gio::FileMonitorEvent event_type);
   bool handle_timeout();
-  void delete_note(const std::string & note_id);
-  void add_or_update_note(const std::string & note_id);
+  void delete_note(const Glib::ustring & note_id);
+  void add_or_update_note(const Glib::ustring & note_id);
   void on_settings_changed(const Glib::ustring & key);
   void sanitize_check_interval(const Glib::RefPtr<Gio::Settings> & settings);
 
   Glib::RefPtr<Gio::FileMonitor> m_file_system_watcher;
 
-  std::map<std::string, NoteFileChangeRecord> m_file_change_records;
-  std::map<std::string, sharp::DateTime> m_note_save_times;
+  std::map<Glib::ustring, NoteFileChangeRecord> m_file_change_records;
+  std::map<Glib::ustring, sharp::DateTime> m_note_save_times;
   sigc::connection m_signal_note_saved_cid;
   sigc::connection m_signal_changed_cid;
   sigc::connection m_signal_settings_changed_cid;
