@@ -3,7 +3,7 @@
  *  It lists note's table of contents in a menu.
  *
  * Copyright (C) 2013 Luc Pionchon <pionchon.luc@gmail.com>
- * Copyright (C) 2013,2015-2016 Aurimas Cernius <aurisc4@gmail.com>
+ * Copyright (C) 2013,2015-2017 Aurimas Cernius <aurisc4@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -381,7 +381,7 @@ void TableofcontentsNoteAddin::on_toc_help_activated()
 {
   gnote::NoteWindow* window = get_window();
   gnote::utils::show_help("gnote", "addin-tableofcontents",
-    window->get_screen()->gobj(), dynamic_cast<Gtk::Window*>(window->host()));
+    *dynamic_cast<Gtk::Window*>(window->host()));
 }
 
 
