@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  */
 
 
-#include <boost/format.hpp>
 #include <glibmm/i18n.h>
 
 #include "debug.hpp"
@@ -46,7 +45,7 @@ WebDavSyncServiceModule::WebDavSyncServiceModule()
 
 
 const char *WebDavSyncServiceAddin::KEYRING_ITEM_NAME = "Tomboy sync WebDAV account";
-std::map<std::string, std::string> WebDavSyncServiceAddin::s_request_attributes;
+std::map<Glib::ustring, Glib::ustring> WebDavSyncServiceAddin::s_request_attributes;
 
 WebDavSyncServiceAddin * WebDavSyncServiceAddin::create()
 {
@@ -61,7 +60,7 @@ Gtk::Widget *WebDavSyncServiceAddin::create_preferences_control(EventHandler req
   table->set_col_spacings(10);
 
   // Read settings out of gconf
-  std::string url, username, password;
+  Glib::ustring url, username, password;
   get_config_settings(url, username, password);
 
   m_url_entry = new Gtk::Entry();
@@ -88,39 +87,39 @@ Gtk::Widget *WebDavSyncServiceAddin::create_preferences_control(EventHandler req
 
 bool WebDavSyncServiceAddin::is_configured()
 {
-  std::string url, username, password;
+  Glib::ustring url, username, password;
   return get_config_settings(url, username, password);
 }
 
 
 bool WebDavSyncServiceAddin::are_settings_valid()
 {
-  std::string url, username, password;
+  Glib::ustring url, username, password;
   return get_pref_widget_settings(url, username, password);
 }
 
 
-std::string WebDavSyncServiceAddin::name()
+Glib::ustring WebDavSyncServiceAddin::name()
 {
   const char *res = _("WebDAV");
   return res;
 }
 
 
-std::string WebDavSyncServiceAddin::id()
+Glib::ustring WebDavSyncServiceAddin::id()
 {
   return "wdfs";
 }
 
-std::string WebDavSyncServiceAddin::fuse_mount_directory_error()
+Glib::ustring WebDavSyncServiceAddin::fuse_mount_directory_error()
 {
   const char *res = _("There was an error connecting to the server.  This may be caused by using an incorrect user name and/or password.");
   return res;
 }
 
-std::vector<std::string> WebDavSyncServiceAddin::get_fuse_mount_exe_args(const std::string & mountPath, bool fromStoredValues)
+std::vector<Glib::ustring> WebDavSyncServiceAddin::get_fuse_mount_exe_args(const Glib::ustring & mountPath, bool fromStoredValues)
 {
-  std::string url, username, password;
+  Glib::ustring url, username, password;
   if(fromStoredValues) {
     get_config_settings(url, username, password);
   }
@@ -131,41 +130,25 @@ std::vector<std::string> WebDavSyncServiceAddin::get_fuse_mount_exe_args(const s
   return get_fuse_mount_exe_args(mountPath, url, username, password, accept_ssl_cert());
 }
 
-std::string WebDavSyncServiceAddin::get_fuse_mount_exe_args_for_display(const std::string & mountPath, bool fromStoredValues)
+Glib::ustring WebDavSyncServiceAddin::get_fuse_mount_exe_args_for_display(const Glib::ustring & mountPath, bool fromStoredValues)
 {
-  /*std::string url, username, password;
-  if(fromStoredValues) {
-    get_config_settings(url, username, password);
-  }
-  else {
-    get_pref_widget_settings(url, username, password);
-  }
-  
-  // Mask password
-  std::string acceptSsl;
-  if(accept_ssl_cert()) {
-    acceptSsl = "-ac";
-  }
-
-  return str(boost::format("%1% -a %2% -u %3% -p %4% %5% -o fsname=gnotewdfs")
-             % mountPath % url % username % password % acceptSsl);*/
-  std::vector<std::string> args = get_fuse_mount_exe_args(mountPath, fromStoredValues);
-  std::string result;
-  for(std::vector<std::string>::iterator iter = args.begin(); iter != args.end(); ++iter) {
-    result += *iter + " ";
+  std::vector<Glib::ustring> args = get_fuse_mount_exe_args(mountPath, fromStoredValues);
+  Glib::ustring result;
+  for(auto iter : args) {
+    result += iter + " ";
   }
 
   return result;
 }
 
-std::string WebDavSyncServiceAddin::fuse_mount_exe_name()
+Glib::ustring WebDavSyncServiceAddin::fuse_mount_exe_name()
 {
   return "wdfs";
 }
 
 bool WebDavSyncServiceAddin::verify_configuration()
 {
-  std::string url, username, password;
+  Glib::ustring url, username, password;
 
   if(!get_pref_widget_settings(url, username, password)) {
     // TODO: Figure out a way to send the error back to the client
@@ -178,7 +161,7 @@ bool WebDavSyncServiceAddin::verify_configuration()
 
 void WebDavSyncServiceAddin::save_configuration_values()
 {
-  std::string url, username, password;
+  Glib::ustring url, username, password;
   get_pref_widget_settings(url, username, password);
 
   save_config_settings(url, username, password);
@@ -191,10 +174,10 @@ void WebDavSyncServiceAddin::reset_configuration_values()
   // TODO: Unmount the FUSE mount!
 }
 
-std::vector<std::string> WebDavSyncServiceAddin::get_fuse_mount_exe_args(const std::string & mountPath, const std::string & url,
-    const std::string & username, const std::string & password, bool acceptSsl)
+std::vector<Glib::ustring> WebDavSyncServiceAddin::get_fuse_mount_exe_args(const Glib::ustring & mountPath, const Glib::ustring & url,
+    const Glib::ustring & username, const Glib::ustring & password, bool acceptSsl)
 {
-  std::vector<std::string> args;
+  std::vector<Glib::ustring> args;
   args.reserve(12);
   args.push_back(url);
   args.push_back(mountPath);
@@ -213,7 +196,7 @@ std::vector<std::string> WebDavSyncServiceAddin::get_fuse_mount_exe_args(const s
   return args;
 }
 
-bool WebDavSyncServiceAddin::get_config_settings(std::string & url, std::string & username, std::string & password)
+bool WebDavSyncServiceAddin::get_config_settings(Glib::ustring & url, Glib::ustring & username, Glib::ustring & password)
 {
   // Retrieve configuration from the GNOME Keyring and GSettings
   url = "";
@@ -236,7 +219,7 @@ bool WebDavSyncServiceAddin::get_config_settings(std::string & url, std::string
   return url != "" && username != "" && password != "";
 }
 
-void WebDavSyncServiceAddin::save_config_settings(const std::string & url, const std::string & username, const std::string & password)
+void WebDavSyncServiceAddin::save_config_settings(const Glib::ustring & url, const Glib::ustring & username, const Glib::ustring & password)
 {
   // Save configuration into the GNOME Keyring and GSettings
   try {
@@ -260,13 +243,15 @@ void WebDavSyncServiceAddin::save_config_settings(const std::string & url, const
     //Preferences.Set ("/apps/tomboy/sync_wdfs_url", url ?? string.Empty);
     //Preferences.Set ("/apps/tomboy/sync_wdfs_username", username ?? string.Empty);
 
-    // TRANSLATORS: %1%: boost format placeholder for the error message.
-    boost::format msg(_("Saving configuration to the GNOME keyring failed with the following message:\n\n%1%"));
-    throw gnote::sync::GnoteSyncException(str(msg % ke.what()).c_str());
+    Glib::ustring msg = Glib::ustring::compose(
+      // TRANSLATORS: %1 is the format placeholder for the error message.
+      _("Saving configuration to the GNOME keyring failed with the following message:\n\n%1"),
+      ke.what());
+    throw gnote::sync::GnoteSyncException(msg.c_str());
   }
 }
 
-bool WebDavSyncServiceAddin::get_pref_widget_settings(std::string & url, std::string & username, std::string & password)
+bool WebDavSyncServiceAddin::get_pref_widget_settings(Glib::ustring & url, Glib::ustring & username, Glib::ustring & password)
 {
   url = sharp::string_trim(m_url_entry->get_text());
   username = sharp::string_trim(m_username_entry->get_text());
@@ -286,7 +271,7 @@ bool WebDavSyncServiceAddin::accept_ssl_cert()
   }
 }
 
-void WebDavSyncServiceAddin::add_row(Gtk::Table *table, Gtk::Widget *widget, const std::string & labelText, uint row)
+void WebDavSyncServiceAddin::add_row(Gtk::Table *table, Gtk::Widget *widget, const Glib::ustring & labelText, uint row)
 {
   Gtk::Label *l = new Gtk::Label(labelText);
   l->set_use_underline(true);
