@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2015-2016 Aurimas Cernius
+ * Copyright (C) 2013,2015-2017 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,9 +40,9 @@ public:
   static MainWindow *present_default(const Note::Ptr & note);
   static bool use_client_side_decorations();
 
-  explicit MainWindow(const std::string & title);
+  explicit MainWindow(const Glib::ustring & title);
 
-  virtual void set_search_text(const std::string & value) = 0;
+  virtual void set_search_text(const Glib::ustring & value) = 0;
   virtual void show_search_bar(bool grab_focus = true) = 0;
   virtual void present_search() = 0;
   virtual void new_note() = 0;
