@@ -306,22 +306,37 @@ namespace gnote {
 
   std::vector<Gtk::Widget*> NoteWindow::get_popover_widgets()
   {
+    std::vector<Gtk::Widget*> widgets;
     std::map<int, Gtk::Widget*> widget_map;
+
+    Gtk::Widget *undo = manage(utils::create_popover_button("win.undo", _("_Undo")));
+    widgets.push_back(undo);
+    Gtk::Widget *redo = manage(utils::create_popover_button("win.redo", _("_Redo")));
+    widgets.push_back(redo);
+    widgets.push_back(NULL);
+
+    Gtk::Widget *link = manage(utils::create_popover_button("win.link", _("_Link to New Note")));
+    widget_map[2000] = link; // place under "note actions", see iactionmanger.hpp
+
     NoteManager & manager = static_cast<NoteManager&>(m_note.manager());
     Note::Ptr note = std::dynamic_pointer_cast<Note>(m_note.shared_from_this());
     FOREACH(NoteAddin *addin, manager.get_addin_manager().get_note_addins(note)) {
       utils::merge_ordered_maps(widget_map, addin->get_actions_popover_widgets());
     }
 
-    std::vector<Gtk::Widget*> widgets;
+    int last_order = 0;
     for(std::map<int, Gtk::Widget*>::iterator iter = widget_map.begin();
         iter != widget_map.end(); ++iter) {
+      // put separator between groups
+      if(iter->first < 10000 && (iter->first / 1000) > last_order && widgets.size() > 0 && widgets.back() != NULL) {
+        widgets.push_back(NULL);
+      }
+      last_order = iter->first / 1000;
       widgets.push_back(iter->second);
     }
 
-    widgets.push_back(utils::create_popover_button("win.important-note", _("Is Important")));
-    widgets.push_back(NULL);
-    widgets.push_back(utils::create_popover_button("win.delete-note", _("_Delete")));
+    widgets.push_back(utils::create_popover_button("win.important-note", _("_Important")));
+    widgets.push_back(utils::create_popover_button("win.delete-note", _("_Delete…")));
 
     return widgets;
   }
@@ -556,8 +571,7 @@ namespace gnote {
 
   void NoteWindow::open_help_activate()
   {
-    utils::show_help("gnote", "editing-notes", get_screen()->gobj(),
-                     dynamic_cast<Gtk::Window*>(host()));
+    utils::show_help("gnote", "editing-notes", *dynamic_cast<Gtk::Window*>(host()));
   }
 
   void NoteWindow::change_depth_right_handler()
@@ -820,20 +834,11 @@ namespace gnote {
       set_position(Gtk::POS_BOTTOM);
       Gtk::Box *menu_box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
 
-      Gtk::Widget *undo = manage(utils::create_popover_button("win.undo", _("_Undo")));
-      menu_box->add(*undo);
-
-      Gtk::Widget *redo = manage(utils::create_popover_button("win.redo", _("_Redo")));
-      menu_box->add(*redo);
-      menu_box->add(*manage(new Gtk::Separator));
-
       // Listen to events so we can sensitize and
       // enable keybinding
       undo_manager.signal_undo_changed().connect(sigc::mem_fun(*this, &NoteTextMenu::undo_changed));
 
       Glib::Quark tag_quark("Tag");
-      Gtk::Widget *link = manage(utils::create_popover_button("win.link", _("_Link")));
-
       Gtk::Widget *bold = create_font_item("win.change-font-bold", _("_Bold"), "b");
       Gtk::Widget *italic = create_font_item("win.change-font-italic", _("_Italic"), "i");
       Gtk::Widget *strikeout = create_font_item("win.change-font-strikeout", _("_Strikeout"), "s");
@@ -848,9 +853,6 @@ namespace gnote {
       Gtk::Widget *large = create_font_size_item(_("_Large"), "large", "size:large");
       Gtk::Widget *huge = create_font_size_item(_("Hu_ge"), "x-large", "size:huge");
 
-      menu_box->add(*link);
-      menu_box->add(*manage(new Gtk::Separator));
-
       auto box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
       utils::set_common_popover_widget_props(*box);
       box->set_name("formatting");
