@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2016 Aurimas Cernius
+ * Copyright (C) 2011-2017 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -98,7 +98,7 @@ class NoteFindHandler
 {
 public:
   NoteFindHandler(Note & );
-  void perform_search(const std::string & text);
+  void perform_search(const Glib::ustring & text);
   bool goto_next_result();
   bool goto_previous_result();
 private:
@@ -136,14 +136,14 @@ public:
   NoteWindow(Note &);
   ~NoteWindow();
 
-  virtual std::string get_name() const override;
-  void set_name(const std::string & name);
+  virtual Glib::ustring get_name() const override;
+  void set_name(const Glib::ustring & name);
   virtual void foreground() override;
   virtual void background() override;
   virtual void hint_size(int & width, int & height) override;
   virtual void size_internals() override;
 
-  virtual void perform_search(const std::string & text) override;
+  virtual void perform_search(const Glib::ustring & text) override;
   virtual bool supports_goto_result() override;
   virtual bool goto_next_result() override;
   virtual bool goto_previous_result() override;
@@ -236,7 +236,7 @@ private:
   void on_save_selection_check_button_toggled();
   void on_save_title_check_button_toggled();
   void on_note_tag_added(const NoteBase&, const Tag::Ptr&);
-  void on_note_tag_removed(const NoteBase::Ptr&, const std::string&);
+  void on_note_tag_removed(const NoteBase::Ptr&, const Glib::ustring&);
   void link_button_clicked();
   void open_help_activate();
   void change_depth_right_handler();
@@ -248,7 +248,7 @@ private:
   void on_text_button_clicked();
 
   Note                        & m_note;
-  std::string                   m_name;
+  Glib::ustring                 m_name;
   int                           m_height;
   int                           m_width;
   Glib::RefPtr<Gtk::AccelGroup> m_accel_group;
