@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2015 Aurimas Cernius
+ * Copyright (C) 2011-2015,2017 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 #define __PREFERENCES_HPP_
 
 #include <map>
-#include <string>
 #include <sigc++/signal.h>
 #include <giomm/settings.h>
 
@@ -93,10 +92,10 @@ namespace gnote {
 
     Preferences();
 
-    Glib::RefPtr<Gio::Settings> get_schema_settings(const std::string & schema);
+    Glib::RefPtr<Gio::Settings> get_schema_settings(const Glib::ustring & schema);
   private:
     Preferences(const Preferences &); // non implemented
-    std::map<std::string, Glib::RefPtr<Gio::Settings> > m_schemas;
+    std::map<Glib::ustring, Glib::RefPtr<Gio::Settings> > m_schemas;
   };
 
 
