@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2016 Aurimas Cernius
+ * Copyright (C) 2013,2016-2017 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,17 +24,15 @@
 #define __UNDO_HPP_
 
 #include <list>
-#include <string>
 #include <stack>
 
-#include <boost/noncopyable.hpp>
-
 #include <sigc++/signal.h>
 #include <gtkmm/textbuffer.h>
 #include <gtkmm/texttag.h>
 #include <gtkmm/textiter.h>
 
 #include "base/macros.hpp"
+#include "noncopyable.hpp"
 #include "notebuffer.hpp"
 #include "utils.hpp"
 
@@ -116,7 +114,7 @@ class InsertAction
   : public SplitterAction
 {
 public:
-  InsertAction(const Gtk::TextIter & start, const std::string & text, int length,
+  InsertAction(const Gtk::TextIter & start, const Glib::ustring & text, int length,
                const ChopBuffer::Ptr & chop_buf);
   virtual void undo(Gtk::TextBuffer * buffer) override;
   virtual void redo(Gtk::TextBuffer * buffer) override;
@@ -220,7 +218,7 @@ private:
 };
 
 class UndoManager
-  : public boost::noncopyable
+  : public gnote::NonCopyable
 {
 public:
   /** the buffer it NOT owned by the UndoManager
