@@ -152,8 +152,7 @@ namespace gnote {
     }
 
 
-    void show_help(const Glib::ustring & filename, const Glib::ustring & link_id,
-                   GdkScreen *screen, Gtk::Window *parent)
+    void show_help(const Glib::ustring & filename, const Glib::ustring & link_id, Gtk::Window & parent)
     {
       // "help:" URIs are "help:document[/page][?query][#frag]"
       // See resolve_help_uri () at,
@@ -164,13 +163,13 @@ namespace gnote {
       }
       GError *error = NULL;
 
-      if(!gtk_show_uri (screen, uri.c_str(), gtk_get_current_event_time (), &error)) {
+      if(!gtk_show_uri_on_window(parent.gobj(), uri.c_str(), gtk_get_current_event_time (), &error)) {
         
         Glib::ustring message = _("The \"Gnote Manual\" could "
                                   "not be found.  Please verify "
                                   "that your installation has been "
                                   "completed successfully.");
-        HIGMessageDialog dialog(parent,
+        HIGMessageDialog dialog(&parent,
                                 GTK_DIALOG_DESTROY_WITH_PARENT,
                                 Gtk::MESSAGE_ERROR,
                                 Gtk::BUTTONS_OK,
@@ -184,13 +183,12 @@ namespace gnote {
     }
 
 
-    void open_url(const Glib::ustring & url)
-      throw (Glib::Error)
+    void open_url(Gtk::Window & parent, const Glib::ustring & url)
     {
       if(!url.empty()) {
         GError *err = NULL;
         DBG_OUT("Opening url '%s'...", url.c_str());
-        gtk_show_uri (NULL, url.c_str(), GDK_CURRENT_TIME, &err);
+        gtk_show_uri_on_window(parent.gobj(), url.c_str(), GDK_CURRENT_TIME, &err);
         if(err) {
           throw Glib::Error(err, true);
         }
@@ -677,8 +675,7 @@ namespace gnote {
     }
 
 
-    TextRange::TextRange(const Gtk::TextIter & _start,
-                         const Gtk::TextIter & _end) throw(sharp::Exception)
+    TextRange::TextRange(const Gtk::TextIter & _start, const Gtk::TextIter & _end)
     {
       if(_start.get_buffer() != _end.get_buffer()) {
         throw(sharp::Exception("Start buffer and end buffer do not match"));
